@@ -180,6 +180,15 @@ module Solve
       'Lockfile'
     end
 
+    # Returns whether this dependency, which has no possible matching
+    # specifications, can safely be ignored.
+    #
+    # @param [Object] dependency
+    # @return [Boolean] whether this dependency can safely be skipped.
+    def allow_missing?(dependency)
+      false
+    end
+
     private
 
       def resolve_with_error_wrapping
